@@ -1,6 +1,6 @@
-## Last Edited: 26/02/15
+## Last Edited: 16/01/16
 
-TwoFactors = function(Response, Factor1, Factor2, HSD=TRUE, AlphaE = 0.05, Data=NULL, Inter=FALSE, 
+TwoFactors = function(Response, Factor1, Factor2, Inter=FALSE, HSD=TRUE, AlphaE = getOption("BrailleR.SigLevel"), Data=NULL, 
     Filename=NULL, Folder=NULL,
     VI=getOption("BrailleR.VI"), Latex=getOption("BrailleR.Latex"), View=getOption("BrailleR.View"))
 {
@@ -51,13 +51,14 @@ with(Data, {
 # create folder and filenames
 if(is.null(Folder)) Folder=DataName
 if(Folder!="" & !file.exists(Folder)) dir.create(Folder)
-if(is.null(Filename)) Filename = paste0(ResponseName, ".", Factor1Name, ".", Factor2Name, "-TwoFactors.Rmd")
+if(is.null(Filename)) Filename = paste0(ResponseName, ".", Factor1Name, ".", Factor2Name, "-TwoFactors", ifelse(Inter, 'WithInt', 'NoInt'), ".Rmd")
 
 # start writing to the R markdown file
-cat('# Analysis of the', DataName, 'data, using', ResponseName, 'as the response variable and the variables', Factor1Name,  'and', Factor2Name, 'as factors.  
-#### Prepared by `r getOption("BrailleR.Author")`  \n\n', file=Filename)
+cat(paste0('# Analysis of the ', DataName, ' data, using ', ResponseName, ' as the response variable and the variables ', Factor1Name,  ifelse(Inter, ", ", " and "), Factor2Name, ifelse(Inter, ", and their interaction", ""), ' as factors.  
+#### Prepared by ', getOption("BrailleR.Author"), '  \n\n'), file=Filename)
 
 cat(paste0('```{r setup, purl=FALSE, include=FALSE}  
+', ifelse(VI, "library(BrailleR)", "library(knitr)"), '
 opts_chunk$set(dev=c("png", "pdf", "postscript", "svg"))  
 opts_chunk$set(echo=FALSE, comment="", fig.path="', Folder, '/', ResponseName, '.', Factor1Name, '.',Factor2Name, '-", fig.width=7)  
 ```    
@@ -67,6 +68,7 @@ opts_chunk$set(echo=FALSE, comment="", fig.path="', Folder, '/', ResponseName, '
 ```{r GroupSummary}  
 attach(', DataName, ')  
 Data.Mean <- aggregate(', ResponseName,', list(', Factor1Name,', ', Factor2Name, '), mean, na.rm=TRUE)
+colnames(Data.Mean) = c("',Factor1Name,'","', Factor2Name,'", "Mean") 
 Data.StDev <- aggregate(', ResponseName,', list(', Factor1Name,', ', Factor2Name, '), sd, na.rm=TRUE)
 nNonMissing <- function(x){
     length(na.omit(x)) # length() includes NAs
@@ -75,7 +77,7 @@ Data.n <- aggregate(', ResponseName,', list(', Factor1Name,', ', Factor2Name, ')
 Data.StdErr = Data.StDev[,3]/sqrt(Data.n[,3])
 detach(', DataName, ')  
 DataSummary = cbind(Data.Mean, Data.StDev[,3], Data.n[,3], Data.StdErr)
-colnames(DataSummary) = c("F1 Level", "F2 Level", "Mean", "Standard deviation", "n", "Standard error")
+colnames(DataSummary) = c("',Factor1Name, ' Level", "',Factor2Name,' Level", "Mean", "Standard deviation", "n", "Standard error")
 ```  
 
 The ratio of the largest group standard deviation to the smallest is `r round(max(Data.StDev[,3])/min(Data.StDev[,3]),2)`  
@@ -93,14 +95,14 @@ print(xtable(DataSummary, caption=TabCapt, label="', ResponseName, 'GroupSummary
     ```  \n\n'), file=Filename, append=TRUE)
 }
 
-############# Produce EDA plots depending on whether interactions are included or not.
+### Produce the EDA plots depending on whether interactions are included or not.
 
 nNonMissing <- function(x){
   length(na.omit(x)) # length() includes NAs
 }
 Data.n <- with(get(DataName), aggregate(get(ResponseName), list(get(Factor1Name),get(Factor2Name)), nNonMissing))
 
-if(isTRUE(Inter)){
+if(Inter){
 if(min(Data.n[,3])>4){
 cat(paste0('## Comparative boxplots
 ```{r boxplots, fig.cap="Comparative boxplots"}  \n',
@@ -108,10 +110,9 @@ ifelse(VI,"VI(",""), 'boxplot(', ResponseName, '~interaction(', Factor1Name, ','
 ```\n\n'), file=Filename, append=TRUE)
 }
 else{
-cat(paste0('## Comparative boxplots
-```{r NoBoxplots, purl=FALSE}  
-cat("When boxplots are not included, it is  because at least one group size is too small.")  
-``` \n\n'), file=Filename, append=TRUE)
+cat(paste0('## Comparative boxplots  
+
+When boxplots are not included, it is  because at least one group size is too small.  \n\n'), file=Filename, append=TRUE)
 }
 }
 else{
@@ -123,36 +124,42 @@ ifelse(VI,"VI(",""), 'boxplot(', ResponseName, '~', Factor2Name, ', data=', Data
 ``` \n\n'), file=Filename, append=TRUE)
 }
 else{
-cat(paste0('## Comparative boxplots
-```{r NoBoxplots, eval=min(Data.n[,3])<5, purl=FALSE}  
-cat("When boxplots are not included, it is  because at least one group size is too small.")  
-``` \n\n'), file=Filename, append=TRUE)
+cat(paste0('## Comparative boxplots  
+
+When boxplots are not included, it is  because at least one group size is too small.   \n\n'), file=Filename, append=TRUE)
 }
 }
 
 cat(paste0('## Comparative dotplots  
 
-```{r dotplots, fig.cap="Comparative dotplots"}  
+```{r Dotplots-by', .simpleCap(Factor1Name), ', fig.cap="Comparative dotplots for ', .simpleCap(ResponseName), ' by ', .simpleCap(Factor1Name), '"}  
 ', ifelse(VI, "VI(", ""), 'stripchart(', ResponseName, '~', Factor1Name, ', data=', DataName, ifelse(VI,")", ""), ')  
-\n', ifelse(VI, "VI(", ""), 'stripchart(', ResponseName, '~', Factor2Name, ', data=', DataName, ifelse(VI,")", ""), ')  
+```  
+
+```{r Dotplots-by', .simpleCap(Factor2Name), ', fig.cap="Comparative dotplots for ', .simpleCap(ResponseName), ' by ', .simpleCap(Factor2Name), '"}  
+', ifelse(VI, "VI(", ""), 'stripchart(', ResponseName, '~', Factor2Name, ', data=', DataName, ifelse(VI,")", ""), ')  
 ``` \n\n'), file=Filename, append=TRUE)
 
 
 #### Interaction plot (if specified)
 
-if(isTRUE(Inter)){
+if(Inter){
   
 F1.Big = length(levels(Data[[Factor2Name]])) < length(levels(Data[[Factor1Name]]))
 xFactor = ifelse(F1.Big ,Factor1Name, Factor2Name)
 Trace = ifelse(!F1.Big, Factor1Name, Factor2Name)
   
-cat(paste0('## Interaction Plot \n
+cat(paste0('## Interaction Plot  
+
 ```{r InteractionPlot, fig.cap="Interaction Plot"}
-with(',DataName, ', interaction.plot(', xFactor, ',', Trace, ',', ResponseName, ')) 
-colnames(Data.Mean) = c("',Factor1Name,'","', Factor2Name,'", "Mean") 
-cat("Means table: Rows are for the trace factor, ', Trace ,', and columns are for the factor along the x-axis, ', xFactor, '.")
+with(',DataName, ', interaction.plot(', xFactor, ',', Trace, ',', ResponseName, '))  
+```  \n\n',
+
+ifelse(VI, "Means table: Rows are for the trace factor, ', .simpleCap(Trace), ', and columns are for the factor along the x-axis, ', .simpleCap(xFactor), '.
+
+```{r }  
 xtabs(Mean~',Trace, '+', xFactor,',data=Data.Mean) 
-```  \n\n'), file=Filename, append=TRUE)
+```  \n\n", "")), file=Filename, append=TRUE)
 }
 
 
@@ -161,11 +168,11 @@ xtabs(Mean~',Trace, '+', xFactor,',data=Data.Mean)
 cat(paste0('## Two-way Analysis of Variance
 
 ```{r TwoWayANOVA}
-MyANOVA <- aov(', ResponseName, '~', Factor1Name, ifelse(isTRUE(Inter),"*","+") , Factor2Name, ', data=', DataName, ')
+MyANOVA <- aov(', ResponseName, '~', Factor1Name, ifelse(Inter, "*", "+") , Factor2Name, ', data=', DataName, ')
 ', ifelse(VI, "VI(MyANOVA)", ""), '
 summary(MyANOVA)  
 if(length(unique(Data.n[,3]))!=1){ 
-MyANOVA2 <- aov(', ResponseName, '~', Factor2Name, ifelse(isTRUE(Inter),"*","+") , Factor1Name, ', data=', DataName, ')
+MyANOVA2 <- aov(', ResponseName, '~', Factor2Name, ifelse(Inter, "*", "+") , Factor1Name, ', data=', DataName, ')
 ', ifelse(VI, "VI(MyANOVA2)", ""),'
 summary(MyANOVA2)
 }
@@ -174,13 +181,13 @@ summary(MyANOVA2)
 if(Latex){
 cat(paste0('```{r ANOVA-TEX, purl=FALSE}  
 library(xtable)  
-ThisTexFile = "', Folder, '/', ResponseName, '-', Factor1Name, '-', Factor2Name, '-ANOVA.tex"  
-TabCapt = "Two-way ANOVA for ', ResponseName, ' with the group factors ', Factor1Name, 'and', Factor2Name, '."  
+ThisTexFile = "', Folder, '/', ResponseName, '-', Factor1Name, '-', Factor2Name, ifelse(Inter, "WithInt", "NoInt"), '-ANOVA.tex"  
+TabCapt = "Two-way ANOVA for ', .simpleCap(ResponseName), ' with the group factors ', .simpleCap(Factor1Name), ' and ', .simpleCap(Factor2Name), ifelse(Inter, ", as well as their interaction", " without their interaction"), '."  
 print(xtable(MyANOVA, caption=TabCapt, label="', ResponseName, '-', Factor1Name, '-ANOVA", digits=4), file = ThisTexFile)  
 ```  \n\n'), file=Filename, append=TRUE)
 }
 
-if(isTRUE(Inter)){
+if(Inter){
 cat(paste0("```{r TwoWayANOVA2, fig.cap=\"Residual analysis\"}
 par(mfrow=c(2,2)) 
 plot(MyANOVA) 
@@ -219,7 +226,7 @@ plot( MyHSD )
 }
 
 # stop writing markdown and process the written file into html and an R script
-knit2html(Filename, quiet=TRUE, stylesheet=system.file("css", "BrailleR.css", package="BrailleR"))
+knit2html(Filename, quiet=TRUE, stylesheet=FindCSSFile(getOption("BrailleR.Style")))
 file.remove(sub(".Rmd", ".md", Filename))
 purl(Filename, quiet=TRUE, documentation=0)
 if(View) browseURL(sub(".Rmd", ".html", Filename))
